@@ -11,19 +11,21 @@
 
 #include <QWidget>
 
-namespace KontactInterface {
+namespace KontactInterface
+{
 class Core;
 class Plugin;
 }
 
-namespace Kontact {
+namespace Kontact
+{
 class SidePaneBase : public QWidget
 {
     Q_OBJECT
 
 public:
     SidePaneBase(KontactInterface::Core *core, QWidget *parent);
-    virtual ~SidePaneBase();
+    ~SidePaneBase() override;
 
     virtual void setCurrentPlugin(const QString &) = 0;
 
